@@ -1,6 +1,5 @@
 """Pytest Plugin."""
 
-
 from __future__ import annotations
 
 import inspect
@@ -13,7 +12,7 @@ from beartype import beartype
 from beartype.typing import Any, Callable, Dict, Iterable, Optional, Union
 from pydantic import BaseModel
 
-from . import AssertConfig, main
+from . import AssertConfig, CacheAssertContainerKeys, main, register, retrieve
 
 
 class TestMetadata(BaseModel):
@@ -46,18 +45,11 @@ class TestMetadata(BaseModel):
         return cls(test_file=rel_test_file.as_posix(), test_name=test_name, func_args=func_args)
 
 
-@pytest.fixture()
-@beartype
-def cache_assert_config() -> AssertConfig:
-    """Configure pytest_cache_assert using `AssertConfig`."""
-    return AssertConfig()
-
-
 @pytest.fixture()
 @beartype
 def assert_against_cache(
     request: FixtureRequest,
-    cache_assert_config: Optional[AssertConfig],
+    cache_assert_config: Optional[AssertConfig] = None,
 ) -> Callable[[Any], None]:
     """Return main.assert_against_cache with pytest-specific arguments already specified.
 
@@ -72,7 +64,9 @@ def assert_against_cache(
         RuntimeError: if the test directory cannot be determined
 
     """
-    cache_assert_config = cache_assert_config or AssertConfig()
+    if cache_assert_config:
+        register(CacheAssertContainerKeys.CONFIG, cache_assert_config)
+    assert_config = retrieve(CacheAssertContainerKeys.CONFIG)
 
     test_dir = None
     for sub_dir in ['tests', 'test']:
@@ -83,7 +77,7 @@ def assert_against_cache(
         raise RuntimeError(f'Could not locate a "tests/" directory in {test_dir}')
 
     # Read user settings
-    path_cache_dir = test_dir / cache_assert_config.cache_dir_rel_path
+    path_cache_dir = test_dir / assert_config.cache_dir_rel_path
 
     # Calculate keyword arguments
     rel_test_file = Path(request.node.fspath).relative_to(test_dir)
